@@ -154,9 +154,9 @@ async def _inplace_change(filename, old_string, new_string):
     writing_file.close()
 
 async def _append_line(filename, line):
-    writing_file = open(filename, "a")
-    writing_file.write(line)
-    writing_file.close()
+    append_file = open(filename, "a")
+    append_file.write(line)
+    append_file.close()
 
 @asyncio.coroutine
 def inplace_change(filename, old_string, new_string):
@@ -197,9 +197,9 @@ class TaskDefs(dict):
             path = Path(os.getcwd())
             self.run_vars = {}
 
-            self.run_vars['dir'] = str(path)
+            directory = str(path)
             if 'dir' in obj:
-                self.run_vars['dir'] = self.run_vars['dir'].replace('$', '') + '/' + obj['dir']
+                directory = self.run_vars['dir'].replace('$', '') + '/' + obj['dir']
 
             if 'condition' in obj:
                 self.run_vars['condition'] = obj['condition'].replace('$', '')
@@ -219,7 +219,7 @@ class TaskDefs(dict):
             if 'task' in obj:
                 logging.debug("Parsing `{}`".format(obj['task']))
                 if isinstance(obj['task'], str):
-                    subtasks.append(Task(obj['task']))
+                    subtasks.append(Task(obj['task'], directory))
                 else:
                     for subspec in obj['task']:
                         try:
@@ -227,7 +227,7 @@ class TaskDefs(dict):
                             subtasks.append(tasks[subspec])
                         except KeyError:
                             #Standard cmd
-                            subtasks.append(Task(subspec))
+                            subtasks.append(Task(subspec, directory))
 
             self.run_vars.update(self.vars)
             
@@ -240,9 +240,10 @@ class TaskDefs(dict):
         
 
 class Task(object):
-    def __init__(self, cmd):
+    def __init__(self, cmd, directory):
         logging.debug('Creating task with command "{}"'.format(cmd))
         self.cmd = cmd
+        self.dir = directory
         self.proc = None
 
     def __str__(self):
@@ -270,6 +271,9 @@ class Task(object):
                 [cmd, " ".join(shlex.quote(token) for token in args)]
             )
         log.info(cmd.replace(env_rnd, ''))
+
+        os.chdir(self.dir)
+
         self.proc = await asyncio.create_subprocess_shell( cmd, stdout=asyncio.subprocess.PIPE, stderr=asyncio.subprocess.PIPE)
         stdout, stderr = await self.proc.communicate()
         print(f'[{cmd.replace(env_rnd, "")} exited with {self.proc.returncode}]')
@@ -346,7 +350,7 @@ class SequentialTaskList(TaskList):
         env = os.environ.copy()
         self.vars.update(env)
 
-        os.chdir(self.vars['dir'])
+#        os.chdir(self.vars['dir'])
 
         if self.condition == False:
             condition = await env_ject(self.vars['condition'])
@@ -393,9 +397,8 @@ class SequentialTaskList(TaskList):
         if 'append' in self.vars:
             if isinstance(self.vars['append'], list):
                 for line in self.vars['append']:
-                    old = await env_ject(line[1])
-                    new = await env_ject(line[2])
-                    await _append_line(line[0], old.format(**self.vars), new.format(**self.vars))
+                    line = await env_ject(line[1])
+                    await _append_line(line[0], line.format(**self.vars))
 
 
     def terminate(self):
@@ -416,7 +419,7 @@ class AsyncTaskList(TaskList):
 #            for i, task in enumerate(self.tasks):
 #                runtasks.append(task.cmd.format(**self.vars))
         # Loop Time
-        os.chdir(self.vars['dir'])
+#        os.chdir(self.vars['dir'])
         await asyncio.wait(
             [task.run() for task in self.tasks],
             return_when=asyncio.FIRST_EXCEPTION,
